@@ -3,10 +3,11 @@ package Travel::Status::DE::URA;
 use strict;
 use warnings;
 use 5.010;
+use utf8;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.02';
+our $VERSION = '2.00';
 
 # create CONSTANTS for different Return Types
 use constant {
@@ -337,6 +338,24 @@ sub results {
 	return @results;
 }
 
+# static
+sub get_services {
+	return (
+		{
+			ura_base    => 'http://ivu.aseag.de/interfaces/ura',
+			ura_version => 1,
+			name        => 'Aachener Straßenbahn und Energieversorgungs AG',
+			shortname   => 'ASEAG',
+		},
+		{
+			ura_base    => 'http://countdown.api.tfl.gov.uk/interfaces/ura',
+			ura_version => 1,
+			name        => 'Transport for London',
+			shortname   => 'TfL',
+		}
+	);
+}
+
 1;
 
 __END__
@@ -365,7 +384,7 @@ API" data providers (e.g. ASEAG)
 
 =head1 VERSION
 
-version 1.02
+version 2.00
 
 =head1 DESCRIPTION
 
@@ -525,7 +544,7 @@ Travel::Status::DE::URA::Result(3pm).
 
 =head1 AUTHOR
 
-Copyright (C) 2013-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2013-2016 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
