@@ -8,7 +8,7 @@ use parent 'Class::Accessor';
 
 use DateTime::Format::Duration;
 
-our $VERSION = '1.02';
+our $VERSION = '2.00';
 
 Travel::Status::DE::URA::Result->mk_ro_accessors(
 	qw(datetime destination line line_id stop stop_id stop_indicator));
@@ -46,6 +46,12 @@ sub date {
 	return $self->datetime->strftime('%d.%m.%Y');
 }
 
+sub platform {
+	my ($self) = @_;
+
+	return $self->{stop_indicator};
+}
+
 sub time {
 	my ($self) = @_;
 
@@ -144,7 +150,7 @@ departure received by Travel::Status::DE::URA
 
 =head1 VERSION
 
-version 1.02
+version 2.00
 
 =head1 DESCRIPTION
 
@@ -188,6 +194,10 @@ The name of the line.
 
 The number of the line.
 
+=item $departure->platform
+
+Shortcut for $departure->stop_indicator, see there.
+
 =item $departure->route_interesting(I<num_stops>)
 
 If the B<results> method of Travel::Status::DE::URA(3pm) was called with
@@ -273,7 +283,7 @@ Travel::Status::DE::URA(3pm), Travel::Status::DE::URA::Stop(3pm).
 
 =head1 AUTHOR
 
-Copyright (C) 2013-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2013-2016 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
